package calendar

  1. Overview
  2. Docs

Module Time.SecondSource

Second implementation

  • since 2.0
Sourcetype t = second

Type of seconds.

Sourceval from_int : int -> t

Convert an integer to an equivalent number of seconds.

Sourceval from_float : float -> t

Convert a float to an equivalent number of seconds.

Sourceval to_int : t -> int

Inverse of from_int.

Sourceval to_float : t -> float

Inverse of from_float.